You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@trafodion.apache.org by hz...@apache.org on 2016/03/01 19:17:06 UTC

[2/3] incubator-trafodion git commit: Rework for [TRAFODION-1850]

Rework for [TRAFODION-1850]


Project: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/commit/76b1b976
Tree: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/tree/76b1b976
Diff: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/diff/76b1b976

Branch: refs/heads/master
Commit: 76b1b976fb2f42f9dbb70dba4a17b998d89c11f1
Parents: f614456
Author: Hans Zeller <hz...@apache.org>
Authored: Tue Mar 1 02:27:17 2016 +0000
Committer: Hans Zeller <hz...@apache.org>
Committed: Tue Mar 1 02:27:17 2016 +0000

----------------------------------------------------------------------
 core/sql/executor/ExFirstN.cpp | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/76b1b976/core/sql/executor/ExFirstN.cpp
----------------------------------------------------------------------
diff --git a/core/sql/executor/ExFirstN.cpp b/core/sql/executor/ExFirstN.cpp
index 20b1cb9..c6093ab 100644
--- a/core/sql/executor/ExFirstN.cpp
+++ b/core/sql/executor/ExFirstN.cpp
@@ -227,11 +227,11 @@ short ExFirstNTcb::work()
 		centry->downState.request = ex_queue::GET_N;
 
 		// if I got a GET_ALL request then send a GET_N request to
 		// my child with the N value being firstNRows_.
 		// if I got a GET_N request, then send the minimum of the
 		// GET_N request value and firstNRows_ to my child.
 		if ((pentry_down->downState.request != ex_queue::GET_N) ||
-		    (pentry_down->downState.requestValue == firstnTdb().firstNRows()))
+		    (pentry_down->downState.requestValue == effectiveFirstN_))
 		  centry->downState.requestValue = effectiveFirstN_;
 		else
 		  {
@@ -227,11 +227,11 @@ short ExFirstNTcb::work()
 
 		// if I got a GET_ALL request then send a GET_N request to
-		// my child with the N value being firstNRows_.
+		// my child with the N value being effectiveFirstN_.
 		// if I got a GET_N request, then send the minimum of the
@@ -227,11 +227,11 @@ short ExFirstNTcb::work()
 		// if I got a GET_N request, then send the minimum of the
-		// GET_N request value and firstNRows_ to my child.
+		// GET_N request value and effectiveFirstN_ to my child.
 		if ((pentry_down->downState.request != ex_queue::GET_N) ||